@@ -101,6 +101,7 @@ class ProductMixin:
         "string_choice",
         "tags",
         "url",
+        "_underscore",
     ]
     readonly_fields = ["id", "is_onsale", "hidden_calculated"]
     ddb_default_filters = [
@@ -139,7 +140,7 @@ class SKUInline(admin.TabularInline):
     fields = ["name", "product", "bob"]
     readonly_fields = ["bob"]
 
-    def bob(self, obj):  # pragma: no cover don't show funcs on inlines test
+    def bob(self, obj):
         return "bob"
 
 
